==> globus-cli-3.4.0.tar.gz: globus-cli-3.4.0/src/globus_cli/parsing/param_types/comma_delimited.py <==
from typing import Callable, Iterable, Optional

import click


class CommaDelimitedList(click.ParamType):
    def __init__(
        self,
        *,
        convert_values: Optional[Callable[[str], str]] = None,
        choices: Optional[Iterable[str]] = None,
    ):
        super().__init__()
        self.convert_values = convert_values
        self.choices = list(choices) if choices is not None else None

    def get_metavar(self, param):
        if self.choices is not None:
            return "{" + ",".join(self.choices) + "}"
        return "TEXT,TEXT,..."

    def convert(self, value, param, ctx):
        value = super().convert(value, param, ctx)
        if value is None:
            return None

        # if `--foo` is a comma delimited list and someone passes
        # `--foo ""`, take that as `foo=[]` rather than foo=[""]
        #
        # the alternative is fine, but we have to choose one and this is
        # probably "closer to what the caller meant"
        #
        # it means that if you take
        # `--foo={",".join(original)}`, you will get a value equal to
        # `original` back if `original=[]` (but not if `original=[""]`)
        resolved = value.split(",") if value else []

        if self.convert_values is not None:
            resolved = [self.convert_values(x) for x in resolved]

        if self.choices is not None:
            bad_values = [x for x in resolved if x not in self.choices]
            if bad_values:
                self.fail(
                    f"the values {bad_values} were not valid choices",
                    param=param,
                    ctx=ctx,
                )

        return resolved

==> globus-cli-3.8.0.tar.gz: globus-cli-3.8.0/src/globus_cli/parsing/param_types/comma_delimited.py <==
from __future__ import annotations

from typing import Callable, Iterable

import click


class CommaDelimitedList(click.ParamType):
    def __init__(
        self,
        *,
        convert_values: Callable[[str], str] | None = None,
        choices: Iterable[str] | None = None,
    ):
        super().__init__()
        self.convert_values = convert_values
        self.choices = list(choices) if choices is not None else None

    def get_metavar(self, param):
        if self.choices is not None:
            return "{" + ",".join(self.choices) + "}"
        return "TEXT,TEXT,..."

    def convert(self, value, param, ctx):
        value = super().convert(value, param, ctx)
        if value is None:
            return None

        # if `--foo` is a comma delimited list and someone passes
        # `--foo ""`, take that as `foo=[]` rather than foo=[""]
        #
        # the alternative is fine, but we have to choose one and this is
        # probably "closer to what the caller meant"
        #
        # it means that if you take
        # `--foo={",".join(original)}`, you will get a value equal to
        # `original` back if `original=[]` (but not if `original=[""]`)
        resolved = value.split(",") if value else []

        if self.convert_values is not None:
            resolved = [self.convert_values(x) for x in resolved]

        if self.choices is not None:
            bad_values = [x for x in resolved if x not in self.choices]
            if bad_values:
                self.fail(
                    f"the values {bad_values} were not valid choices",
                    param=param,
                    ctx=ctx,
                )

        return resolved
